@@ -2,10 +2,10 @@ package Mojolicious::Plugin::TtRenderer;
 
 use strict;
 use warnings;
-use 5.010001;
+use 5.016;
 
 # ABSTRACT: Template Renderer Plugin for Mojolicious
-our $VERSION = '1.58'; # VERSION
+our $VERSION = '1.62'; # VERSION
 
 use base 'Mojolicious::Plugin';
 
@@ -38,7 +38,7 @@ Mojolicious::Plugin::TtRenderer - Template Renderer Plugin for Mojolicious
 
 =head1 VERSION
 
-version 1.58
+version 1.62
 
 =head1 SYNOPSIS
 
@@ -46,15 +46,15 @@ L<Mojolicious::Lite>:
 
  plugin 'tt_renderer';
 
-L<Mojolicious>
+L<Mojolicious>:
 
  $self->plugin('tt_renderer');
 
 =head1 DESCRIPTION
 
-This plugin is a simple Template Toolkit renderer for L<Mojolicious>. 
-Its defaults are usually reasonable, although for finer grain detail in 
-configuration you may want to use 
+This plugin is a simple Template Toolkit renderer for L<Mojolicious>.
+Its defaults are usually reasonable, although for finer grain detail in
+configuration you may want to use
 L<Mojolicious::Plugin::TtRenderer::Engine> directly.
 
 =for stopwords Bjørn
@@ -69,7 +69,7 @@ These are the options that can be passed in as arguments to this plugin.
 
 =head2 template_options
 
-Configuration hash passed into L<Template>'s constructor, see 
+Configuration hash passed into L<Template>'s constructor, see
 L<Template Toolkit's configuration summary|Template#CONFIGURATION-SUMMARY>
 for details.  Here is an example using the L<Mojolicious::Lite> form:
 
@@ -89,7 +89,7 @@ Here is the same example using the full L<Mojolicious> app form:
  
  sub startup {
    my($self) = @_;
-   
+ 
    $self->plugin('tt_renderer' => {
      template_options => {
        PRE_CHOMP => 1,
@@ -97,7 +97,7 @@ Here is the same example using the full L<Mojolicious> app form:
        TRIM => 1,
      },
    }
-   
+ 
    ...
  }
 
@@ -163,7 +163,9 @@ The current controller instance can be accessed as C<c>.
 
 =head1 EXAMPLES
 
-L<Mojolicious::Lite> example:
+=over 4
+
+=item L<Mojolicious::Lite> example:
 
  use Mojolicious::Lite;
  
@@ -179,8 +181,8 @@ L<Mojolicious::Lite> example:
  __DATA__
  
  @@ index.html.tt
- [% 
-    WRAPPER 'layouts/default.html.tt' 
+ [%
+    WRAPPER 'layouts/default.html.tt'
     title = 'Welcome'
  %]
  <p>Welcome to the Mojolicious real-time web framework!</p>
@@ -194,7 +196,9 @@ L<Mojolicious::Lite> example:
    <body>[% content %]</body>
  </html>
 
-L<Mojolicious> example:
+=item L<Mojolicious> example:
+
+C<lib/MyApp.pm>:
 
  package MyApp;
  use Mojo::Base 'Mojolicious';
@@ -208,6 +212,8 @@ L<Mojolicious> example:
  
  1;
 
+C<lib/MyApp/Example.pm>:
+
  package MyApp::Example;
  use Mojo::Base 'Mojolicious::Controller';
  
@@ -222,15 +228,38 @@ L<Mojolicious> example:
  
  1;
 
+C<templates/example/welcome.html.tt>:
+
+ [%
+   WRAPPER 'layouts/default.html.tt'
+   title = 'Welcome'
+ %]
+ <h2>[% message %]</h2>
+ This page was generated from the template "templates/example/welcome.html.tt"
+ and the layout "templates/layouts/default.html.tt",
+ <a href="[% url_for %]">click here</a> to reload the page or
+ <a href="/index.html">here</a> to move forward to a static page.
+ [% END %]
+
+C<templates/layouts/default.html.tt>:
+
+ <!DOCTYPE html>
+ <html>
+   <head><title>[% title %]</title></head>
+   <body>[% content %]</body>
+ </html>
+
+=back
+
 These are also included with the C<Mojolicious::Plugin::TtRenderer>
-distribution, including the support files required for the full 
+distribution, including the support files required for the full
 L<Mojolicious> app example.
 
 =head1 SEE ALSO
 
-L<Mojolicious::Plugin::TtRenderer::Engine>, 
-L<Mojolicious>, 
-L<Mojolicious::Guides>, 
+L<Mojolicious::Plugin::TtRenderer::Engine>,
+L<Mojolicious>,
+L<Mojolicious::Guides>,
 L<http://mojolicious.org>.
 
 =head1 AUTHOR
@@ -273,9 +302,13 @@ uwisser
 
 Dinis Lage
 
+jay mortensen (GMORTEN)
+
+Matthew Lawrence (MATTLAW)
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by Ask Bjørn Hansen.
+This software is copyright (c) 2009-2021 by Ask Bjørn Hansen.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
